--[[
Name: Babble-Herbs-2.2
Revision: $Rev: 24289 $
Authors(s): kagaro (sal.scotto@gmail.com)
Website: www.wowace.com
Documentation: http://www.wowace.com/wiki/Babble-Herbs-2.2
SVN: http://svn.wowace.com/root/branch/Babble-2.2/Babble-Herbs-2.2
Dependencies: AceLibrary, AceLocale-2.2
License: MIT
]]

local MAJOR_VERSION = "Babble-Herbs-2.2"
local MINOR_VERSION = tonumber(string.sub("$Revision: 24289 $", 12, -3))

if not AceLibrary then error(MAJOR_VERSION .. " requires AceLibrary") end
if not AceLibrary:HasInstance("AceLocale-2.2") then error(MAJOR_VERSION .. " requires AceLocale-2.2") end

local _, x = AceLibrary("AceLocale-2.2"):GetLibraryVersion()
MINOR_VERSION = MINOR_VERSION * 100000 + x

if not AceLibrary:IsNewVersion(MAJOR_VERSION, MINOR_VERSION) then return end

local BabbleHerbs = AceLibrary("AceLocale-2.2"):new(MAJOR_VERSION)

local herbSkills = {}

BabbleHerbs:RegisterTranslations("enUS", function() return {
	["Peacebloom"] = true,
	["Silverleaf"] = true,
	["Earthroot"] = true,
	["Mageroyal"] = true,
	["Briarthorn"] = true,
	["Swiftthistle"] = true,
	["Stranglekelp"] = true,
	["Bruiseweed"] = true,
	["Wild Steelbloom"] = true,
	["Grave Moss"] = true,
	["Kingsblood"] = true,
	["Liferoot"] = true,
	["Fadeleaf"] = true,
	["Goldthorn"] = true,
	["Khadgar's Whisker"] = true,
	["Wintersbite"] = true,
	["Firebloom"] = true,
	["Purple Lotus"] = true,
	["Wildvine"] = true,
	["Arthas' Tears"] = true,
	["Sungrass"] = true,
	["Blindweed"] = true,
	["Ghost Mushroom"] = true,
	["Gromsblood"] = true,
	["Golden Sansam"] = true,
	["Dreamfoil"] = true,
	["Mountain Silversage"] = true,
	["Plaguebloom"] = true,
	["Icecap"] = true,
	["Bloodvine"] = true,
	["Black Lotus"] = true,
	["Felweed"] = true,
	["Dreaming Glory"] = true,
	["Terocone"] = true,
	["Ancient Lichen"] = true,
	["Blood Thistle"] = true,
	["Mana Thistle"] = true,
	["Netherbloom"] = true,
	["Nightmare Vine"] = true,
	["Ragveil"] = true,
	["Flame Cap"] = true,
	["Fel Lotus"] = true,
	
} end)

herbSkills = {
	["Peacebloom"] = 1,
	["Silverleaf"] = 1,
	["Earthroot"]  = 15,
	["Mageroyal"]  = 50,
	["Briarthorn"] = 70,
	["Swiftthistle"] = 0,
	["Stranglekelp"] = 85,
	["Bruiseweed"] = 100,
	["Wild Steelbloom"] = 115,
	["Grave Moss"] = 120,
	["Kingsblood"] = 125,
	["Liferoot"] = 150,
	["Fadeleaf"] = 160,
	["Goldthorn"] = 170,
	["Khadgar's Whisker"] = 185,
	["Wintersbite"] = 195,
	["Firebloom"] = 205,
	["Purple Lotus"] = 210,
	["Wildvine"] = 0,
	["Arthas' Tears"] = 220,
	["Sungrass"] = 230,
	["Blindweed"] = 235,
	["Ghost Mushroom"] = 245,
	["Gromsblood"] = 250,
	["Golden Sansam"] = 260,
	["Dreamfoil"] = 270,
	["Mountain Silversage"] = 280,
	["Plaguebloom"] = 285,
	["Icecap"] = 290,
	["Bloodvine"] = 0,
	["Black Lotus"] = 300,
	["Felweed"] = 300,
	["Dreaming Glory"] = 315,
	["Terocone"] = 325,
	["Ancient Lichen"] = 375,
	["Blood Thistle"] = 0,
	["Mana Thistle"] = 375,
	["Netherbloom"] = 350,
	["Nightmare Vine"] = 365,
	["Ragveil"] = 325,
	["Flame Cap"] = 335,
	["Fel Lotus"] = 0,
}
BabbleHerbs:Debug()
BabbleHerbs:SetStrictness(true)

function BabbleHerbs:GetSkill(herb)
	self:argCheck(herb, 2, "string")
	local skill = herbSkills[herb] or herbSkills[self:HasReverseTranslation(herb) and self:GetReverseTranslation(herb) or false]
	if not skill then
		return nil
	end
	return skill
end

function BabbleHerbs:HasNode(herb)
	self:argCheck(herb, 2, "string")
	local skill = herbSkills[herb] or herbSkills[self:HasReverseTranslation(herb) and self:GetReverseTranslation(herb) or false]
	if not skill then
		return false
	end
	return skill > 0
end

AceLibrary:Register(BabbleHerbs, MAJOR_VERSION, MINOR_VERSION)
BabbleHerbs = nil