--[[
Name: Babble-Ore-2.2
Revision: $Rev: 24289 $
Authors(s): kagaro (sal.scotto@gmail.com)
Website: www.wowace.com
Documentation: http://www.wowace.com/wiki/Babble-Ore-2.2
SVN: http://svn.wowace.com/root/branch/Babble-2.2/Babble-Ore-2.2
Dependencies: AceLibrary, AceLocale-2.2
License: MIT
]]

local MAJOR_VERSION = "Babble-Ore-2.2"
local MINOR_VERSION = tonumber(string.sub("$Revision: 24289 $", 12, -3))

if not AceLibrary then error(MAJOR_VERSION .. " requires AceLibrary") end
if not AceLibrary:HasInstance("AceLocale-2.2") then error(MAJOR_VERSION .. " requires AceLocale-2.2") end

local _, x = AceLibrary("AceLocale-2.2"):GetLibraryVersion()
MINOR_VERSION = MINOR_VERSION * 100000 + x

if not AceLibrary:IsNewVersion(MAJOR_VERSION, MINOR_VERSION) then return end

local BabbleOre = AceLibrary("AceLocale-2.2"):new(MAJOR_VERSION)

local veinSkill = {}
local veinTypes = {}

BabbleOre:RegisterTranslations("enUS", function() return {
-- Ore
	["Copper Ore"] = true,
	["Tin Ore"] = true,
	["Silver Ore"] = true,
	["Iron Ore"] = true,
	["Gold Ore"] = true,
	["Mithril Ore"] = true,
	["Dark Iron Ore"] = true,
	["Truesilver Ore"] = true,
	["Throium Ore"] = true,
	["Elementium Ore"] = true,
	["Fel Iron Ore"] = true,
	["Adamantite Ore"] = true,
	["Eternium Ore"] = true,
	["Khroium Ore"] = true,
-- Types
	["Copper"] = true,
	["Tin"] = true,
	["Silver"] = true,
	["Iron"] = true,
	["Gold"] = true,
	["Mithril"] = true,
	["Dark Iron"] = true,
	["Truesilver"] = true,
	["Thorium"] = true,
	["Elementium"] = true,
	["Fel Iron"] = true,
	["Adamantite"] = true,
	["Eternium"] = true,
	["Khorium"] = true,
	["Incendicite"] = true,
	["Lesser Bloodstone"] = true,
	["Indurium"] = true,
	["Large Obsidian Shard"] = true,
	["Small Obsidian Shard"] = true,
-- Quest Ore
	["Underlight Ore"] = true, -- copper and tin
	["Lead Ore"] = true,
	["Rethban Ore"] = true, --quest
	["Incendicite Ore"] = true,
	["Umbral Ore"] = true,
	["Elunite Ore"] = true,
	["Lesser Bloodstone Ore"] = true, --quest
	["Indurium Ore"] = true,
-- Nodes
	["Copper Vein"] = true,
	["Tin Vein"] = true,
	["Iron Deposit"] = true,
	["Silver Vein"] = true,
	["Gold Vein"] = true,
	["Mithril Deposit"] = true,
	["Ooze Covered Mithril Deposit"] = true,
	["Truesilver Deposit"] = true,
	["Ooze Covered Silver Vein"] = true,
	["Ooze Covered Gold Vein"] = true,
	["Ooze Covered Truesilver Deposit"] = true,
	["Ooze Covered Rich Thorium Vein"] = true,
	["Ooze Covered Thorium Vein"] = true,
	["Small Thorium Vein"] = true,
	["Rich Thorium Vein"] = true,
	["Hakkari Thorium Vein"] = true,
	["Dark Iron Deposit"] = true,
	["Lesser Bloodstone Deposit"] = true,
	["Incendicite Mineral Vein"] = true,
	["Indurium Mineral Vein"] = true,
	["Fel Iron Deposit"] = true,
	["Adamantite Deposit"] = true,
	["Rich Adamantite Deposit"] = true,
	["Khorium Vein"] = true,
	["Large Obsidian Chunk"] = true,
	["Small Obsidian Chunk"] = true,
	
} end)

veinSkill = {
	["Copper Vein"] = 1,
	["Tin Vein"] = 65,
	["Iron Deposit"] = 125,
	["Silver Vein"] = 75,
	["Gold Vein"] = 155,
	["Mithril Deposit"] = 175,
	["Ooze Covered Mithril Deposit"] = 175,
	["Truesilver Deposit"] = 230,
	["Ooze Covered Silver Vein"] = 75,
	["Ooze Covered Gold Vein"] = 155,
	["Ooze Covered Truesilver Deposit"] = 230,
	["Ooze Covered Rich Thorium Vein"] = 275,
	["Ooze Covered Thorium Vein"] = 245,
	["Small Thorium Vein"] = 245,
	["Rich Thorium Vein"] = 275,
	["Hakkari Thorium Vein"] = 245,
	["Dark Iron Deposit"] = 230,
	["Lesser Bloodstone Deposit"] = 75,
	["Incendicite Mineral Vein"] = 65,
	["Indurium Mineral Vein"] = 150,
	["Fel Iron Deposit"] = 300,
	["Adamantite Deposit"] = 325,
	["Rich Adamantite Deposit"] = 350,
	["Khorium Vein"] = 375,
	["Large Obsidian Chunk"] = 305,
	["Small Obsidian Chunk"] = 305,
}
veinType = {
	["Copper Vein"] = "Copper",
	["Tin Vein"] = "Tin",
	["Iron Deposit"] = "Iron",
	["Silver Vein"] = "Silver",
	["Gold Vein"] = "Gold",
	["Mithril Deposit"] = "Mithril",
	["Ooze Covered Mithril Deposit"] = "Mithril",
	["Truesilver Deposit"] = "Truesilver",
	["Ooze Covered Silver Vein"] = "Silver",
	["Ooze Covered Gold Vein"] = "Gold",
	["Ooze Covered Truesilver Deposit"] = "Truesilver",
	["Ooze Covered Rich Thorium Vein"] = "Thorium",
	["Ooze Covered Thorium Vein"] = "Throium",
	["Small Thorium Vein"] = "Thorium",
	["Rich Thorium Vein"] = "Thorium",
	["Hakkari Thorium Vein"] = "Thorium",
	["Dark Iron Deposit"] = "Dark Iron",
	["Lesser Bloodstone Deposit"] = "Lesser Bloodstone",
	["Incendicite Mineral Vein"] = "Incendicite",
	["Indurium Mineral Vein"] = "Indurium",
	["Fel Iron Deposit"] = "Fel Iron",
	["Adamantite Deposit"] = "Adamantite",
	["Rich Adamantite Deposit"] = "Adamantite",
	["Khorium Vein"] = "Khorium",
	["Large Obsidian Chunk"] = "Large Obsidian Chunk",
	["Small Obsidian Chunk"] = "Small Obsidian Chunk",
	
}
BabbleOre:Debug()
BabbleOre:SetStrictness(true)

-- what skill to mine this vein
function BabbleOre:GetVeinSkill(vein)
	self:argCheck(vein, 2, "string")
	local skill = veinSkill[vein] or veinSkill[self:HasReverseTranslation(vein) and self:GetReverseTranslation(vein) or false]
	if not skill then
		return nil
	end
	return skill
end
-- is this a mineral vein
function BabbleOre:IsVein(vein)
	self:argCheck(vein, 2, "string")
	local skill = veinSkill[vein] or veinSkill[self:HasReverseTranslation(vein) and self:GetReverseTranslation(vein) or false]
	if not skill then
		return false
	end
	return skill > 0
end
-- what type of ore comes from this node?
function BabbleOre:GetOreType(vein)
	self:argCheck(vein,2,"string")
	local otype = veinType[vein] or veinType[self:HasReverseTranslation(vein) and self:GetReverseTranslation(vein) or false]
	if not otype then
		return nil
	end
	return otype
end
-- is this a 'rich' vein
function BabbleOre:IsRichVein(vein)
	self:argCheck(vein, 2, "string")
	if veinSkill[vein] then
		return vein:match("Rich") or vein:match("Large")
	elseif veinSkill[self:HasReverseTranslation(vein)] then
		return vein:match("Rich") or vein:match("Large")
	else
		return false
	end
end
AceLibrary:Register(BabbleOre, MAJOR_VERSION, MINOR_VERSION)
BabbleOre = nil